@@ -5,18 +5,24 @@ use App::Netdisco::Worker::Plugin;
 use aliased 'App::Netdisco::Worker::Status';
 
 use App::Netdisco::Util::Worker;
-use App::Netdisco::Util::Permission qw/check_acl_no check_acl_only/;
+use App::Netdisco::Util::Permission qw/acl_matches acl_matches_only/;
 
 register_worker({ phase => 'late' }, sub {
   my ($job, $workerconf) = @_;
   my $count = 0;
 
+  my $best = $job->best_status;
+  if (Status->$best->level != Status->done->level) {
+      return Status
+        ->info(sprintf ' [%s] hooks - skipping due to incomplete job', $job->device);
+  }
+
   foreach my $conf (@{ setting('hooks') }) {
     my $no   = ($conf->{'filter'}->{'no'}   || []);
     my $only = ($conf->{'filter'}->{'only'} || []);
 
-    next if check_acl_no( $job->device, $no );
-    next unless check_acl_only( $job->device, $only);
+    next if acl_matches( $job->device, $no );
+    next unless acl_matches_only( $job->device, $only);
 
     if ($conf->{'event'} eq 'arpnip') {
       $count += queue_hook('arpnip', $conf);
